"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createCrud = void 0;
var _menus = require("./crud/menus.crud");
var _blockCategories = require("./crud/blockCategories.crud");
var _pageBlocks = require("./crud/pageBlocks.crud");
var _pageTemplates = require("./crud/pageTemplates.crud");
var _categories = require("./crud/categories.crud");
var _pages = require("./crud/pages.crud");
var _pages2 = require("./crud/pages.validation");
var _pageElements = require("./crud/pageElements.crud");
var _settings = require("./crud/settings.crud");
var _system = require("./crud/system.crud");
var _api = require("@webiny/api");
var _pubsub = require("@webiny/pubsub");
var _error = _interopRequireDefault(require("@webiny/error"));
var _PagesPermissions = require("./crud/permissions/PagesPermissions");
var _MenusPermissions = require("./crud/permissions/MenusPermissions");
var _CategoriesPermissions = require("./crud/permissions/CategoriesPermissions");
var _BlockCategoriesPermissions = require("./crud/permissions/BlockCategoriesPermissions");
var _PageTemplatesPermissions = require("./crud/permissions/PageTemplatesPermissions");
var _PageBlocksPermissions = require("./crud/permissions/PageBlocksPermissions");
var _plugins = require("../plugins");
var _createDataSourcesContext = require("../dataSources/context/createDataSourcesContext");
// This setup (using the `createPageBuilder` factory function) is just a starting point.
// The rest of the Page Builder application should be rewritten and use the same approach as well.
// Ultimately, this `createPageBuilder` factory function should be located in package root.
// So, for example: `packages/api-page-builder/src/createPageBuilder.ts`.
const createPageBuilder = () => {
  let prerenderingHandlers = {
    render: async () => {
      // empty
    },
    flush: async () => {
      // empty
    }
  };
  return {
    onPageBeforeRender: (0, _pubsub.createTopic)("pageBuilder.onPageBeforeRender"),
    onPageAfterRender: (0, _pubsub.createTopic)("pageBuilder.onPageAfterRender"),
    onPageBeforeFlush: (0, _pubsub.createTopic)("pageBuilder.onPageBeforeFlush"),
    onPageAfterFlush: (0, _pubsub.createTopic)("pageBuilder.onPageAfterFlush"),
    setPrerenderingHandlers: handlers => {
      prerenderingHandlers = handlers;
    },
    getPrerenderingHandlers: () => prerenderingHandlers
  };
};
const setup = params => {
  const {
    storageOperations
  } = params;
  const plugin = new _api.ContextPlugin(async context => {
    if (context.pageBuilder) {
      throw new _error.default("PbContext setup must be first loaded.", "CONTEXT_SETUP_ERROR");
    }
    const getTenantId = () => {
      return context.tenancy.getCurrentTenant().id;
    };
    const getLocaleCode = () => {
      const locale = context.i18n.getContentLocale();
      if (!locale) {
        throw new _error.default("Missing content locale in API Page Builder.");
      }
      return locale.code;
    };
    if (storageOperations.beforeInit) {
      try {
        await storageOperations.beforeInit(context);
      } catch (ex) {
        throw new _error.default(ex.message || "Could not run before init in Page Builder storage operations.", ex.code || "STORAGE_OPERATIONS_BEFORE_INIT_ERROR", {
          ...ex
        });
      }
    }
    const menusPermissions = new _MenusPermissions.MenusPermissions({
      getIdentity: context.security.getIdentity,
      getPermissions: () => context.security.getPermissions("pb.menu"),
      fullAccessPermissionName: "pb.*"
    });
    const pagesPermissions = new _PagesPermissions.PagesPermissions({
      getIdentity: context.security.getIdentity,
      getPermissions: () => context.security.getPermissions("pb.page"),
      fullAccessPermissionName: "pb.*"
    });
    const categoriesPermissions = new _CategoriesPermissions.CategoriesPermissions({
      getIdentity: context.security.getIdentity,
      getPermissions: () => context.security.getPermissions("pb.category"),
      fullAccessPermissionName: "pb.*"
    });
    const blockCategoriesPermissions = new _BlockCategoriesPermissions.BlockCategoriesPermissions({
      getIdentity: context.security.getIdentity,
      getPermissions: () => context.security.getPermissions("pb.blockCategory"),
      fullAccessPermissionName: "pb.*"
    });
    const pageBlocksPermissions = new _PageBlocksPermissions.PageBlocksPermissions({
      getIdentity: context.security.getIdentity,
      getPermissions: () => context.security.getPermissions("pb.block"),
      fullAccessPermissionName: "pb.*"
    });
    const pageTemplatesPermissions = new _PageTemplatesPermissions.PageTemplatesPermissions({
      getIdentity: context.security.getIdentity,
      getPermissions: () => context.security.getPermissions("pb.template"),
      fullAccessPermissionName: "pb.*"
    });
    const system = await (0, _system.createSystemCrud)({
      context,
      storageOperations,
      getTenantId
    });
    const settings = (0, _settings.createSettingsCrud)({
      context,
      storageOperations,
      getTenantId,
      getLocaleCode
    });
    const menus = (0, _menus.createMenuCrud)({
      context,
      storageOperations,
      menusPermissions,
      getTenantId,
      getLocaleCode
    });
    const categories = (0, _categories.createCategoriesCrud)({
      context,
      storageOperations,
      categoriesPermissions,
      pagesPermissions,
      getTenantId,
      getLocaleCode
    });
    const blockCategories = (0, _blockCategories.createBlockCategoriesCrud)({
      context,
      storageOperations,
      blockCategoriesPermissions,
      getTenantId,
      getLocaleCode
    });
    const pageBlocks = (0, _pageBlocks.createPageBlocksCrud)({
      context,
      storageOperations,
      pageBlocksPermissions,
      getTenantId,
      getLocaleCode
    });
    const pageElements = (0, _pageElements.createPageElementsCrud)({
      context,
      storageOperations,
      pagesPermissions,
      getTenantId,
      getLocaleCode
    });
    const pages = (0, _pages.createPageCrud)({
      context,
      storageOperations,
      pagesPermissions,
      getTenantId,
      getLocaleCode
    });
    const pageTemplates = (0, _pageTemplates.createPageTemplatesCrud)({
      context,
      storageOperations,
      pageTemplatesPermissions,
      getTenantId,
      getLocaleCode
    });
    context.pageBuilder = {
      ...createPageBuilder(),
      ...system,
      ...settings,
      ...menus,
      ...pages,
      ...pageElements,
      ...categories,
      ...blockCategories,
      ...pageBlocks,
      ...pageTemplates
    };
    if (!storageOperations.init) {
      return;
    }
    try {
      await storageOperations.init(context);
    } catch (ex) {
      throw new _error.default(ex.message || "Could not run init in Page Builder storage operations.", ex.code || "STORAGE_OPERATIONS_INIT_ERROR", {
        ...ex
      });
    }
  });
  plugin.name = "page-builder.createContext";
  return plugin;
};
const createCrud = params => {
  return [new _plugins.JsonpackContentCompressionPlugin(), new _plugins.GzipContentCompressionPlugin(), setup(params),
  /**
   * We must have default compression in the page builder.
   * Maybe figure out some other way of registering the plugins.
   */
  /**
   * Add validation.
   */
  (0, _pages2.createPageValidation)(),
  /**
   * Add DataSources context.
   */
  (0, _createDataSourcesContext.createDataSourcesContext)()];
};
exports.createCrud = createCrud;

//# sourceMappingURL=crud.js.map